"""Описание программы"""

Программа бинарного поиска.
Все основные модули находятся в папке package.
Каждый модуль выполняет определённую функцию:
   binary_search.py - реализует функцию бинарного поиска;
   main.py - реализует интерфейс командной строки;
   __main__.py - точка входа;
   __init__.py - метод инициализации.
Для использования примеров работы функции при запуске __main__.py используйте '-e' и укажите номер примера.
Для использования doctest для тестирования функции необходимо запустить файл binary_search.py как отельный модуль.
Для использования pytest для тестирования функции необходимо запустить pytest в директории project\package.
Для использования своих значений при запуске __main__.py используйте '-l' и укажите список чисел, используйте '-n' и укажите искомое число.